// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

import QtQuick
import QtQuick.Templates as T
import QtQuick.Controls.impl
import QtQuick.Controls.Material
import QtQuick.Controls.Material.impl

T.TabButton {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding)

    padding: 12
    spacing: 6

    property alias myIcon: icon.text

    contentItem: Column {
        Label {
            id: icon
            width: 24
            height: 24
            horizontalAlignment: Qt.AlignHCenter
            anchors.horizontalCenter: parent.horizontalCenter
            font.family: Constants.iconFont.font.family
            font.pixelSize: Constants.iconSize
            color: !control.enabled ? control.Material.hintTextColor
                                    : control.down || control.checked ? control.Material.accentColor
                                                                      : control.Material.foreground
        }

        Label {
            id: text
            horizontalAlignment: Qt.AlignHCenter
            width: parent.width
            text: control.text
            font: control.font
            color: !control.enabled ? control.Material.hintTextColor
                                    : control.down || control.checked ? control.Material.accentColor
                                                                      : control.Material.foreground
        }
    }

    background: Ripple {
        implicitHeight: control.Material.touchTarget

        clip: true
        pressed: control.pressed
        anchor: control
        active: enabled && (control.down || control.visualFocus || control.hovered)
        color: control.Material.rippleColor
        //clipRadius: 0
    }
}
