// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

import QtQuick
import QtQuick.Templates as T
import QtQuick.Controls.impl
import QtQuick.Controls.Material
import QtQuick.Controls.Material.impl

T.AbstractButton {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: 16
    verticalPadding: Material.menuItemVerticalPadding
    spacing: 16

    property string subText: ""

    contentItem: Column {
        id: column

        property int labelWidth: control.width - control.leftPadding - control.rightPadding

        Label {
            width: column.labelWidth
            text: control.text
            font.family: control.font.family
            font.pixelSize: Constants.lgTextSize
            color: control.enabled ? Material.primaryTextColor : Material.secondaryTextColor
        }

        Label {
            visible: control.subText !== ""
            width: column.labelWidth
            text: control.subText
            font.family: control.font.family
            font.pixelSize: Constants.mdTextSize
            wrapMode: Text.WordWrap
            color: Material.secondaryTextColor
        }
    }

    background: Rectangle {
        implicitWidth: 200
        implicitHeight: control.Material.menuItemHeight
        color: "transparent"

        Ripple {
            width: parent.width
            height: parent.height
            clip: visible
            pressed: control.pressed
            anchor: control
            active: control.down
            color: control.Material.rippleColor
        }
    }
}
