// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

Flickable {
    id: root
    interactive: true
    contentHeight: mainLayout.height
    boundsMovement: Flickable.StopAtBounds
    boundsBehavior: Flickable.DragAndOvershootBounds

    ColumnLayout {
        id: mainLayout
        anchors.left: parent.left
        anchors.right: parent.right
        spacing: 0

        Label {
            id: title
            Layout.margins: 20
            text: qsTr("Settings")
            font.pixelSize: Constants.xlTextSize
        }

        SwitchSettingsItem {
            Layout.fillWidth: true
            horizontalPadding: 20
            text: qsTr("Auto-scale")
            subText: qsTr("Tries to scale the project to fit to current display and orientation. May not work with all projects.")
            checked: backend.autoScaleProject() ? Qt.Checked : Qt.Unchecked
            onToggled: backend.setAutoScaleProject(checked)
        }

        SwitchSettingsItem {
            Layout.fillWidth: true
            horizontalPadding: 20
            text: qsTr("Keep screen on")
            subText: qsTr("Prevents the device from going to sleep while the app is running")
            checked: backend.keepScreenOn() ? Qt.Checked : Qt.Unchecked
            onToggled: backend.setKeepScreenOn(checked)
        }

        SettingsItem {
            Layout.fillWidth: true
            horizontalPadding: 20
            text: qsTr("Send feedback")
        }

        SettingsItem {
            Layout.fillWidth: true
            horizontalPadding: 20
            text: qsTr("About")
            subText: backend.buildInfo()
            enabled: false
        }
    }
}
