// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

import QtQuick
import QtQuick.Templates as T
import QtQuick.Controls.impl
import QtQuick.Controls.Material
import QtQuick.Controls.Material.impl

T.AbstractButton {
    id: control

    checkable: true

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: 16
    verticalPadding: Material.menuItemVerticalPadding
    spacing: 16

    property string subText: ""

    indicator: Switch {
        id: switchIndicator
        x: control.width - switchIndicator.indicator.width - control.rightPadding
        y: control.topPadding + (control.availableHeight - height) / 2
        visible: control.checkable
        checked: control.checked
        padding: 0
        z: -1 // Otherwise Switch can be clicked independently instead of the button itself
    }

    contentItem: Column {
        id: column

        property int labelWidth: control.width - control.leftPadding - control.rightPadding - switchIndicator.indicator.width - 6

        Label {
            width: column.labelWidth
            text: control.text
            font.family: control.font.family
            font.pixelSize: Constants.lgTextSize
        }

        Label {
            width: column.labelWidth
            text: control.subText
            font.family: control.font.family
            font.pixelSize: Constants.mdTextSize
            wrapMode: Text.WordWrap
            color: Material.secondaryTextColor
        }
    }

    background: Item {
        implicitWidth: 200
        implicitHeight: control.Material.menuItemHeight

        Ripple {
            width: parent.width
            height: parent.height

            clip: visible
            pressed: control.pressed
            anchor: control
            active: control.down
            color: control.Material.rippleColor
        }
    }
}
