// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
#pragma once

#include <QObject>
#include <QWebSocketServer>

#include "ds.h"

class DesignStudioManager : public QObject
{
    Q_OBJECT
public:
    explicit DesignStudioManager(const QString &deviceUuid, QObject *parent = nullptr);

    void init();

public slots:
    void sendProjectStarting(const QString &id);
    void sendProjectRunning(const QString &id);
    void sendProjectStopped(const QString &id);
    void sendProjectLogs(const QString &id, const QString &logs);
    QString getDesignStudioIp(const QString &id) const;
    bool disconnectDesignStudio(const QString &id);
    void disconnectAllDesignStudios();

private:
    // Network
    QWebSocketServer m_webSocketServer;
    QTimer m_discoveryTimer;

    // Connected Design Studios
    QList<QSharedPointer<DesignStudio>> m_designStudios;

    // other members
    const QString m_deviceUuid;

    void incomingConnection();

signals:
    void projectVersionMismatch(const QString &expected, const QString &got);
    void projectIncoming(const QString &id, const int &projectSize);
    void projectIncomingProgress(const QString &id, const int percentage);
    void projectReceived(const QString &id, const QByteArray &project);
    void designStudioConnected(const QString &id, const QString &ipAddr);
    void designStudioDisconnected(const QString &id, const QString &ipAddr);
    void allDesignStudiosDisconnected();
    void projectStopRequested(const QString &id);
};
