/****************************************************************************
**
** Copyright (C) 2023 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Design Viewer of the Qt Toolkit.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include <QApplication>
#include <QQmlContext>
#include <QQmlEngine>

#include "backend.h"
#include "logger.h"

int main(int argc, char *argv[])
{
    Logger::instance();

    qDebug() << "Starting Qt Design Viewer";
    qputenv("QML_COMPAT_RESOLVE_URLS_ON_ASSIGNMENT", "1");

    QApplication app(argc, argv);
    QApplication::setOrganizationName("Qt");
    QApplication::setApplicationName(QStringLiteral("Qt Design Viewer"));
    QApplication::setApplicationVersion(QString("Built on %1 %2").arg(__DATE__, __TIME__));

    Backend backend;

    QQuickView view;
    view.engine()->rootContext()->setContextProperty("backend", &backend);
    view.setSource(QUrl(QStringLiteral("qrc:/qt/qml/AndroidUI/Main.qml")));
    view.setResizeMode(QQuickView::SizeRootObjectToView);

#ifdef Q_OS_ANDROID
    view.showMaximized();
#else
    view.show();
#endif

    return app.exec();
}
