// Copyright (C) 2024 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

#pragma once

#include <QList>
#include <QMediaCaptureSession>
#include <QRect>
#include <QVideoWidget>

class CustomVideoWidget : public QVideoWidget
{
    Q_OBJECT
public:
    explicit CustomVideoWidget(QWidget *parent = nullptr)
        : QVideoWidget(parent)
    {}

    ~CustomVideoWidget() override {}
    void closeEvent(QCloseEvent *) override { emit closed(); }

signals:
    void closed();
};

class QrScanner : public QObject
{
    Q_OBJECT
public:
    ~QrScanner();
    void scanQrCode();

private:
    QSharedPointer<QMediaCaptureSession> m_captureSession;
    CustomVideoWidget *m_videoWidget;
    QAtomicInt m_processing;

    void openCamera();

signals:
    void qrCodeScanned(const QString &qrCode);
    void windowClosed();
};
